<?php

namespace Phaxio\PhaxioPublic;

class AreaCodeCollection extends \Phaxio\AbstractResourceCollection
{
    protected $resource = 'public/area_codes';
    protected $resource_class = 'PhaxioPublic\\AreaCode';
}
