<?php

// autoload_classmap.php @generated by Composer

$vendorDir = dirname(dirname(__FILE__));
$baseDir = dirname($vendorDir);

return array(
    'Composer\\InstalledVersions' => $vendorDir . '/composer/InstalledVersions.php',
    'Phaxio' => $vendorDir . '/phaxio/phaxio/lib/Phaxio.php',
    'Phaxio\\OperationResult' => $vendorDir . '/phaxio/phaxio/lib/Phaxio/OperationResult.php',
    'Phaxio\\Error\\AuthenticationException' => $vendorDir . '/phaxio/phaxio/lib/Phaxio/Error/AuthenticationException.php',
    'Phaxio\\Error\\NotFoundException' => $vendorDir . '/phaxio/phaxio/lib/Phaxio/Error/NotFoundException.php',
    'Phaxio\\Error\\InvalidRequestException' => $vendorDir . '/phaxio/phaxio/lib/Phaxio/Error/InvalidRequestException.php',
    'Phaxio\\Error\\RateLimitException' => $vendorDir . '/phaxio/phaxio/lib/Phaxio/Error/RateLimitException.php',
    'Phaxio\\Error\\APIConnectionException' => $vendorDir . '/phaxio/phaxio/lib/Phaxio/Error/APIConnectionException.php',
    'Phaxio\\Error\\GeneralException' => $vendorDir . '/phaxio/phaxio/lib/Phaxio/Error/GeneralException.php',
);
